
# Authentication service

## What it does

This service provides two endpoints relative to the authentication of a user:

* A login endpoint that will allow a user to authenticate itself using its credentials (a username and an encrypted password). When the credentials are correct it will generate a JSON Web Token and set it as a cookie for the domain name specified in the configuration of the service. An xsrf token will also be returned in the response. Both the cookie and the xsrf token will be needed to make authenticated calls later.

* A logout endpoint, which signs out the user by deprecating the cookie set with the login endpoint.

This service also provides endpoints to retrieve and update a user profile.

## How it works

![authentication-service](../../assets/authentication-service.png)

The entrypoint of the service is a REST API provided by a [NestJS](https://github.com/nestjs/nest) application. It depends on two other services:

* The Legacy Authentication Middleware to verify the identity of the user and retrieve its profile (called through our api gateway: Kong)
* The Admin API of Kong to get the user specific secrets in order to sign the JSON Web Tokens

## API documentation

NestJS provides a swagger module that can be easily integrated. Using specific annotations alongside your endpoints declaration, this module will automatically generates a swagger documentation, reachable at `/api-docs`.

## Service health

NestJS provides a [health module](https://github.com/nestjs/terminus) based on Terminus, that gives you the opportunity to declare predifined or custom health indicators. It exposes the health status of the service at `/health`.  
This service will return a `200` http status code when all indicators are healthy. Otherwise it will return a `503` http status code. 

For this service we declared two health indicators that: 
* the Kong API gateway is up
* the legacy authentication middleware is up

## Stats

We are using a Node module called [swagger-stats](http://swaggerstats.io/).  
It traces API calls, monitors API performance and usage statistics. It exposes the metrics in different formats, such as Prometheus format, so you may use Prometheus and Graphana for API monitoring and alterting.  
Those metrics are available at `/swagger-stats/metrics`.

For more information about this module, visit the [official swagger-stat page](http://swaggerstats.io/docs.html).

## Docker
It is possible to run this service using Docker containers, using the `docker-compose.yml` and `Dockerfile` files.  
For more information, refer to the project [authentication-service][add a link]